@@ -182,72 +182,6 @@ sub use_trusted {
 
 }
 
-=head3 get_properties
-
-Returns an array reference, being each index an attribute of the C<DTS::Task::ExecutePackage>, 
-using the sequence described below:
-
-=over
-
-=item 0
-name
-
-=item 1
-description
-
-=item 2 
-type
-
-=item 3
-package_id
-
-=item 4
-package_name
-
-=item 5
-package_password
-
-=item 6
-server_name
-
-=item 7
-server_username
-
-=item 8
-server_password
-
-=item 9
-uses_repository
-
-=item 10
-file_name
-
-=item 11
-use_trusted
-
-=item 12
-input_vars
-
-=back
-
-=cut
-
-sub get_properties {
-
-    my $self = shift;
-
-    return [
-        $self->get_name,            $self->get_description,
-        $self->get_type,            $self->get_package_id,
-        $self->get_package_name,    $self->get_package_password,
-        $self->get_server_name,     $self->get_server_username,
-        $self->get_server_password, $self->uses_repository,
-        $self->get_file_name,       $self->use_trusted,
-        $self->get_input_vars
-    ];
-
-}
-
 sub to_string {
 
     my $self = shift;
